==> centreon-web-24.04.12.tar.gz: centreon-web-24.04.12/src/Core/Service/Infrastructure/API/FindRealTimeUniqueServiceNames/FindRealTimeUniqueServiceNamesController.php <==
<?php

/*
 * Copyright 2005 - 2023 Centreon (https://www.centreon.com/)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * For more information : contact@centreon.com
 *
 */

declare(strict_types=1);

namespace Core\Service\Infrastructure\API\FindRealTimeUniqueServiceNames;

use Centreon\Application\Controller\AbstractController;
use Core\Service\Application\UseCase\FindRealTimeUniqueServiceNames\FindRealTimeUniqueServiceNames;
use Core\Service\Application\UseCase\FindRealTimeUniqueServiceNames\FindRealTimeUniqueServiceNamesPresenterInterface;
use Symfony\Component\HttpFoundation\Response;

final class FindRealTimeUniqueServiceNamesController extends AbstractController
{
    /**
     * @param FindRealTimeUniqueServiceNames $useCase
     * @param FindRealTimeUniqueServiceNamesPresenterInterface $presenter
     *
     * @return Response
     */
    public function __invoke(FindRealTimeUniqueServiceNames $useCase, FindRealTimeUniqueServiceNamesPresenterInterface $presenter): Response
    {
        $this->denyAccessUnlessGrantedForApiRealtime();

        $useCase($presenter);

        return $presenter->show();
    }
}

==> centreon-web-24.10.17.tar.gz: centreon-web-24.10.17/src/Core/Service/Infrastructure/API/FindRealTimeUniqueServiceNames/FindRealTimeUniqueServiceNamesController.php <==
<?php

/*
 * Copyright 2005 - 2023 Centreon (https://www.centreon.com/)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * For more information : contact@centreon.com
 *
 */

declare(strict_types=1);

namespace Core\Service\Infrastructure\API\FindRealTimeUniqueServiceNames;

use Centreon\Application\Controller\AbstractController;
use Core\Service\Application\UseCase\FindRealTimeUniqueServiceNames\FindRealTimeUniqueServiceNames;
use Core\Service\Application\UseCase\FindRealTimeUniqueServiceNames\FindRealTimeUniqueServiceNamesPresenterInterface;
use Symfony\Component\HttpFoundation\Response;

final class FindRealTimeUniqueServiceNamesController extends AbstractController
{
    /**
     * @param FindRealTimeUniqueServiceNames $useCase
     * @param FindRealTimeUniqueServiceNamesPresenterInterface $presenter
     *
     * @return Response
     */
    public function __invoke(
        FindRealTimeUniqueServiceNames $useCase,
        FindRealTimeUniqueServiceNamesPresenterInterface $presenter,
    ): Response {
        $this->denyAccessUnlessGrantedForApiRealtime();

        $useCase($presenter);

        return $presenter->show();
    }
}
